@@ -36,6 +36,7 @@
 
 class Deck;
 class VCard;
+class MainWindow;
 
 /**
  * CardBox is a GUI tray that holds all 5 rows of widgets that 
@@ -50,7 +51,7 @@ class VCard;
 class CardBox : public Gtk::HBox
 {
 public:
-	CardBox ();
+	CardBox (MainWindow& mwin_);
 	~CardBox ();
 
 	void new_file ();
@@ -133,6 +134,8 @@ private:
 										   const string& rel_fname_);
 
 private:
+	MainWindow& m_mwin;
+
 	std::vector<CardBoxIF> m_cbs;       // GUI representation of a box
 
 	Glib::RefPtr<Gdk::Pixbuf> m_drawer_empty;
