@@ -240,7 +240,7 @@ dump_to_file ()
 	cardlist_const_iterator iter = begin ();
 	while (iter != end ()) {
 		vcard = *iter;
-		fdump << Glib::locale_from_utf8 (
+		fdump << Granule::locale_from_utf8 (
 			Granule::trim_multiline (vcard->get_question ()));
 		fdump << " ";
 		fdump << vcard->get_expiration ().fmtString ().c_str ();
@@ -267,12 +267,12 @@ export_sound_bits (const std::string& path_)
 	string from_path;
 	vector<string> v;
 	
-	from_path = Glib::filename_to_utf8 (CONFIG->get_snd_archive_path ());
+	from_path = Granule::filename_to_utf8 (CONFIG->get_snd_archive_path ());
 	from_path += G_DIR_SEPARATOR_S;
 
 	cardlist_const_iterator citer = m_cards.begin ();
 	while (citer != m_cards.end ()) {
-		word = Glib::locale_from_utf8 ((*citer)->get_question ());
+		word = Granule::locale_from_utf8 ((*citer)->get_question ());
 		ASSA::Utils::split (word.c_str (), v);
 		if (v.size () > 1) {
 			word = v[0] != "to" ? v[0] : v[1];
