@@ -67,7 +67,7 @@ Deck (DeckEditStatus status_)
 {
 	trace_with_mask("Deck::Deck",GUITRACE|DECK);
 
-	m_active_snd_path = Glib::filename_to_utf8(CONFIG->get_snd_archive_path ());
+	m_active_snd_path = Granule::filename_to_utf8(CONFIG->get_snd_archive_path ());
 	init_appearance ();
 }
 
@@ -83,12 +83,12 @@ Deck (const string& fname_, DeckEditStatus status_)
 {
 	trace_with_mask("Deck::Deck(untitled)",GUITRACE|DECK);
 
-	m_author   = Glib::locale_to_utf8   (CONFIG->get_user_name ());
-	m_active_snd_path = Glib::filename_to_utf8(CONFIG->get_snd_archive_path ());
+	m_author   = Granule::locale_to_utf8   (CONFIG->get_user_name ());
+	m_active_snd_path = Granule::filename_to_utf8(CONFIG->get_snd_archive_path ());
 
 	{
 		ASSA::TimeVal today = ASSA::TimeVal::gettimeofday ();
-		m_desc += Glib::locale_to_utf8 (today.fmtString ("%c"));
+		m_desc += Granule::locale_to_utf8 (today.fmtString ("%c"));
 	}
 	init_appearance ();
 	dump_deck_status ();
@@ -221,7 +221,7 @@ parse_xml_tree (xmlDocPtr parser_, std::string& error_msg_)
 	if (result) {
 		DL ((APP,"/deck/sound_path = \"%s\"\n", (const char*) result));
 		if (strlen ((const char*) result) != 0) {
-			m_snd_path = Glib::locale_from_utf8 ((const char*) result);
+			m_snd_path = Granule::locale_from_utf8 ((const char*) result);
 			m_active_snd_path = m_snd_path;
 		}
 		xmlFree (result);
@@ -1145,7 +1145,7 @@ save ()
 	ret = xmlTextWriterWriteElement (writer, BAD_CAST "description", 
 									 BAD_CAST m_desc.c_str ());
 	ret = xmlTextWriterWriteElement (writer, BAD_CAST "sound_path", 
-						 BAD_CAST Glib::locale_to_utf8 (m_snd_path).c_str ());
+						 BAD_CAST Granule::locale_to_utf8 (m_snd_path).c_str ());
 
     //--------------------------------------------------------
 	ret = xmlTextWriterStartElement (writer, BAD_CAST "appearance");
@@ -1334,11 +1334,11 @@ play_card (SideSelection side_, Deck::cardlist_iterator& iter_)
 
 	DL ((GRAPP,"play card for side '%s'\n", (side_==FRONT?"Front":"Back")));
 
-	w = Glib::locale_from_utf8 ((*iter_)->get_alt_spelling (side_));
+	w = Granule::locale_from_utf8 ((*iter_)->get_alt_spelling (side_));
 
 	if (w.length () == 0) 
 	{
-		w = Glib::locale_from_utf8 ((*iter_)->get_question ());
+		w = Granule::locale_from_utf8 ((*iter_)->get_question ());
 		ASSA::Utils::split (w.c_str (), v);
 		if (v.size () > 1) 
 		{
@@ -1399,6 +1399,7 @@ play_card (SideSelection side_, Deck::cardlist_iterator& iter_)
 	ASSA::Fork::fork_exec (CONFIG->get_snd_player_cmd (), 
 						   execmdbuf, ASSA::Fork::IGNORE_STATUS);
 #endif
+
 }
 
 /** 
@@ -1496,7 +1497,7 @@ set_snd_path (const string& spath_)
 {
 	trace_with_mask("Deck::set_snd_path",GUITRACE|DECK);
 
-	m_snd_path = Glib::locale_from_utf8 (spath_.c_str ());
+	m_snd_path = Granule::locale_from_utf8 (spath_.c_str ());
 	DL ((APP,"Testing new snd_path \"%s\"\n", m_snd_path.c_str ()));
 
 	if (m_snd_path.length () > 0) {
@@ -1504,7 +1505,7 @@ set_snd_path (const string& spath_)
 	}
 	else {
 		m_active_snd_path = 
-			Glib::filename_to_utf8(CONFIG->get_snd_archive_path ());
+			Granule::filename_to_utf8(CONFIG->get_snd_archive_path ());
 	}
 
 	test_active_snd_path ();
