@@ -325,7 +325,11 @@ DeckInfo (Gtk::Window& parent_, Deck& deck_)
 	ok_button->set_flags  (Gtk::CAN_FOCUS);
 	ok_button->set_relief (Gtk::RELIEF_NORMAL);
 
+#ifdef GLIBMM_PROPERTIES_ENABLED
 	get_action_area ()->property_layout_style ().set_value (Gtk::BUTTONBOX_END);
+#else
+	get_action_area ()->set_property ("layout_style", Gtk::BUTTONBOX_END);
+#endif
 
 	DI_SET_LABEL(author_label);
 	author_alignment->add (*author_label);
@@ -403,7 +407,12 @@ DeckInfo (Gtk::Window& parent_, Deck& deck_)
 	scrollw->set_flags (Gtk::CAN_FOCUS);
 	scrollw->set_shadow_type (Gtk::SHADOW_NONE);
 	scrollw->set_policy (Gtk::POLICY_AUTOMATIC , Gtk::POLICY_AUTOMATIC);
+
+#ifdef GLIBMM_PROPERTIES_ENABLED
 	scrollw->property_window_placement ().set_value (Gtk::CORNER_TOP_LEFT);
+#else
+	scrollw->set_property ("window_placement", Gtk::CORNER_TOP_LEFT);
+#endif
 
 	scrollw->add (*all_vbox);
 	get_vbox ()->pack_start (*scrollw);
@@ -460,7 +469,7 @@ on_browse_clicked ()
 	}
 
     if (f.run () == Gtk::RESPONSE_OK) {
-        m_snd_path_entry->set_text (Glib::filename_from_utf8(f.get_filename()));
+        m_snd_path_entry->set_text (Granule::filename_from_utf8(f.get_filename()));
     }
 }
 
