@@ -68,7 +68,7 @@ DeckList () : m_selected_deck (NULL)
 	
 	/** Enable column sorting
 	 */
-	column->set_sort_column_id (m_columns.m_name);
+	column->set_sort_column (m_columns.m_name);
 	column->set_sort_indicator (true);
 
 	m_tree_sel_ref = m_tree_view.get_selection ();
@@ -269,7 +269,7 @@ on_drag_begin (const Glib::RefPtr<Gdk::DragContext>& context_)
 		x_pos = 20;
 
 		Glib::RefPtr<Gdk::Pixbuf> dnd_pixbuf =
-		   Gdk::Pixbuf::create_from_file(GRAPPDATDIR "/pixmaps/copy_deck.png");
+			Granule::create_from_file(GRAPPDATDIR "/pixmaps/copy_deck.png");
 
 		context_->set_icon (dnd_pixbuf, x_pos, cell_height/2);
 	}
