@@ -35,13 +35,13 @@
 #include <gtkmm/toolbar.h>
 
 #ifdef IS_HILDON
-#include <hildon-widgetsmm/appview.h>
+#   include <hildon-libsmm.h>
 #endif
 
 class VDeck;
 
 #ifdef IS_HILDON 
-class DeckView : public Hildon::AppView
+class DeckView : public Hildon::Window
 #else
 class DeckView : public Gtk::Dialog
 #endif
