@@ -282,7 +282,11 @@ GeometryPrefs (PrefWindow& pwin_)
 	scrollw->set_flags (Gtk::CAN_FOCUS);
 	scrollw->set_shadow_type (Gtk::SHADOW_NONE);
 	scrollw->set_policy (Gtk::POLICY_AUTOMATIC , Gtk::POLICY_ALWAYS);
+#ifdef GLIBMM_PROPERTIES_ENABLED
 	scrollw->property_window_placement ().set_value (Gtk::CORNER_TOP_LEFT);
+#else
+	scrollw->set_property ("window_placement", Gtk::CORNER_TOP_LEFT);
+#endif
 
 	Gtk::VBox* scrollw_vbox = Gtk::manage (new Gtk::VBox (false, 0));
 
