@@ -48,19 +48,14 @@ create ()
 		f.push_back (MenuElem ("_Preferences", 
 							   mem_fun (m_mw, &MainWindow::pref_cb)));
 		m_preferences = &f.back ();
-#ifndef IS_HILDON
+//#ifndef IS_HILDON
 		f.push_back (SeparatorElem ());
 		f.push_back (MenuElem ("_Exit", 
 							   mem_fun (m_mw, &MainWindow::exit_cb)));
 		m_exit = &f.back ();
-#endif
+//#endif
 
-		// Assemble (backwards?)
-#ifdef IS_HILDON	
-		MenuList& list_bar = m_mw.get_menu ()->items ();
-#else
 		MenuList& list_bar = m_menu_bar->items ();
-#endif
 
 		list_bar.push_back (MenuElem ("_File", 
 									  Gtk::AccelKey("<control>f"), 
