@@ -2,7 +2,7 @@
 //------------------------------------------------------------------------------
 //                              VDeck.h
 //------------------------------------------------------------------------------
-// $Id: VDeck.h,v 1.8 2006/08/30 12:22:36 vlg Exp $
+// $Id: VDeck.h,v 1.9 2006/12/18 03:33:15 vlg Exp $
 //
 //  Copyright (c) 2004,2006 by Vladislav Grinchenko
 //
@@ -60,7 +60,8 @@ public:
 	virtual void erase     (cardlist_iterator iter_) = 0;
 	virtual bool erase     (VCard* card_)            = 0;
 
-	virtual void play_card (VDeck::cardlist_iterator& iter_) = 0;
+	virtual void play_card (SideSelection side_,
+							VDeck::cardlist_iterator& iter_) = 0;
 
 	virtual const string&  get_name (void) const = 0;
 	virtual int get_index () const { return -1; }
